/**
 * includes go here.
 *
 * Copyright (C) 2003 International Business Machines, Inc.
 *
 *	This program is free software; you can redistribute it and/or modify it
 *	under the terms of the GNU General Public License as published by the
 *	Free Software Foundation version 2 of the License.
 *
 *	This program is distributed in the hope that it will be useful, but
 *	WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *	General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License along
 *	with this program; if not, write to the Free Software Foundation, Inc.,
 *	675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * 	need api in libsysfs to get one attribute of one particular device.
 *	also an api to get all attributes of one device.
 *
 */


#ifndef _SYSDIAG_H_
#define _SYSDIAG_H_

#include <errno.h>
#include <ctype.h>
#include <stdio.h>
#include <unistd.h>
#include <string.h>
#include <stdlib.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <dirent.h>
#include <mntent.h>
#include "libsysfs.h"



#define LOG_FILE 	" /var/log/messages"
#define GREP_OP 	"grep -i "

#define SCSI_INFO 	"sginfo -i "
#define SCSI_STAT 	"sginfo -c -C -d -Flogical -e -f -g -s -D -n -p -V "
#define SCSI_TEST 	"sg_test_rwbuf "

#define NET_INFO 	"ethtool -i "
#define NET_STAT 	"ethtool -S "
#define NET_TEST 	"ethtool -t "

#define SYSDIAG_FILE 	"/tmp/.sysdiag"
#define SG_MAP 		"sg_map -x > /tmp/.sysdiag"


#define DIAG_SHOW_VALUE		0x0001
#define DIAG_DIAG_INFO		0x0002
#define DIAG_DEVICE       	0x0004
#define DIAG_LIST         	0x0008
#define DIAG_INQ          	0x0010
#define DIAG_LOGS         	0x0020
#define DIAG_STAT         	0x0040
#define DIAG_TEST         	0x0080
#define DIAG_ALL          	0x0100
#define DIAG_DRIVER       	0x0200
#define DIAG_PAUSE        	0x0400
#define DIAG_BUS          	0x0800
#define DIAG_TOPO         	0x1000
#define DIAG_CLASS       	0x2000


#define CMD_OPTIONS "b:c:dilr:psthxv?"
#define CONF_FILE "/usr/local/share/sysdiag.conf"


struct section {
	struct section *next;
	char *name;
	char *buf;
};

struct diags {
	struct diags *next;
	char *name;
	char *inq;
	char *test;
	char *stat;
};


int DIAG_OPTIONS;
int DIAG_LEVEL; 

char DEVICE_NAME[SYSFS_NAME_LEN];
char DRIVER_NAME[SYSFS_NAME_LEN];
char CLASS_NAME[SYSFS_NAME_LEN];
char TOPO_NAME[SYSFS_NAME_LEN];
char BUS_NAME[SYSFS_NAME_LEN];
char SYSFS_MOUNT_PATH[SYSFS_PATH_MAX];


extern int list_main(void);
extern struct diags * parse_main(struct diags *);
extern int free_diag(struct diags *diag);
extern char * show_logs(char *);
extern int show_sysfs_root(char *rootname);

#endif /* _SYSDIAG_H_ */
